# Convert

```sh
automesh convert --help
<!-- cmdrun automesh convert --help -->
```

## Input/Output File Types

```sh
spn -> npy
npy -> spn
inp -> exo | mesh | vtk
(todo) mesh -> exo | inp | vtk
```
